@@ -189,3 +189,97 @@ class ZoomClient:
             return None
         else:
             return response.json()
+
+    def getPhoneNumberID(self, numberToFind, nextPageToken=None):
+        if nextPageToken is not None:
+            url = f"{self.baseUrl}/phone/numbers?page_size=100&next_page_token={nextPageToken}"
+        else:
+            url = f"{self.baseUrl}/phone/numbers?page_size=100"
+
+        payload = {}
+        headers = {
+            'Authorization': f'Bearer {self.accessToken}'
+        }
+        response = requests.request("GET", url, headers=headers, data=payload).json()
+        try:
+            nextPageToken = response["next_page_token"]
+        except:
+            return "ID not found"
+        for number in response["phone_numbers"]:
+            if numberToFind == number['number']:
+                numberID = number["id"]
+                return numberID
+        return self.getPhoneNumberID(numberToFind ,nextPageToken)
+
+
+    def listAllCommonAreas(self):
+        url = f"{self.baseUrl}/phone/common_areas"
+        payload = {}
+        headers = {
+            'Authorization': f'Bearer {self.accessToken}'
+        }
+        response = requests.request("GET", url, headers=headers, data=payload)
+        return response.json()
+
+    def getCommonArea(self, commonAreaID):
+        url = f"{self.baseUrl}/phone/common_areas/{commonAreaID}"
+        payload = {}
+        headers = {
+            'Authorization': f'Bearer {self.accessToken}'
+        }
+        response = requests.request("GET", url, headers=headers, data=payload)
+        return response.json()
+
+
+    def addCommonArea(self, callingPlanType, extension, displayName, siteID):
+        url = f"{self.baseUrl}/phone/common_areas"
+        payload = json.dumps({
+            "calling_plans": [
+                {
+                    "type": callingPlanType
+                }
+            ],
+            "country_iso_code": "US",
+            "display_name": displayName,
+            "extension_number": extension,
+            "site_id": siteID,
+            "timezone": "America/Phoenix"
+        })
+        headers = {
+            'Authorization': f'Bearer {self.accessToken}',
+            'Content-Type': 'application/json',
+        }
+        response = requests.request("POST", url, headers=headers, data=payload)
+        return response.json()
+
+
+    def assignPhoneNumberToCommonArea(self, commonAreaID, phoneNumber, phoneNumberID):
+        url = f"{self.baseUrl}/phone/common_areas/{commonAreaID}/phone_numbers"
+        payload = json.dumps({
+            "phone_numbers": [
+                {
+                    "id": phoneNumberID,
+                    "number": phoneNumber
+                }
+            ]
+        })
+        headers = {
+            'Authorization': f'Bearer {self.accessToken}',
+            'Content-Type': 'application/json',
+        }
+        response = requests.request("POST", url, headers=headers, data=payload)
+        return response.json()
+
+    def updateCommonArea(self, commonAreaID, jsonChanges):
+        url = f"{self.baseUrl}/phone/common_areas/{commonAreaID}"
+        payload = jsonChanges
+        headers = {
+            'Authorization': f'Bearer {self.accessToken}',
+            'Content-Type': 'application/json',
+        }
+        response = requests.request("PATCH", url, headers=headers, data=payload)
+        if response.status_code == 204:
+            return None
+        else:
+            return response.json()
+
